Django Alapage
==============

[![Build Status](https://travis-ci.org/synw/django-alapage.svg?branch=master)](https://travis-ci.org/synw/django-alapage) 

Page management application with slideshows for Django. 
The pages are editable in a wysiwyg editor or in a html/css code editor in the admin interface.

Features
--------

- Edit page in a wysiwyg editor or code editor
- Page level permissions management
- Fullscreen inline edit

Screenshots
-----------

Pages can be edited in wysiwyg mode or code mode with ( [django-ckeditor](https://github.com/django-ckeditor/django-ckeditor) ) 
or ( [django-codemirror2](https://github.com/sk1p/django-codemirror2) )

![Editors](https://raw.github.com/synw/django-alapage/master/docs/img/editors.png)

Documentation
-------------

Read the [documentation](http://django-alapage.readthedocs.io/en/latest/)

Todo
----

- [ ] More tests
- [ ] Ability to choose from wysiwig editor or code editor depending on the user preference

